from .kafka_connect import KafkaConnect

import click
import json

@click.group()
@click.version_option()
@click.option('--endpoint', default='http://localhost:8083', envvar='KAFKA_CONNECT_ENDPOINT', help='The base URL for the Kafka Connect REST API.')
@click.pass_context
def cli(ctx, endpoint):
    """A command-line client for the Confluent Platform Kafka Connect REST API."""
    ctx.obj = KafkaConnect(endpoint)

@cli.command()
@click.pass_obj
def get_cluster(kafka_connect):
    """Get the version and other details of the Kafka Connect cluster.
    
    Examples:
        $ kc get-cluster
    """
    cluster = kafka_connect.get_cluster()
    click.echo(json.dumps(cluster))

@cli.command()
@click.argument('connector')
@click.pass_obj
def get_connector(kafka_connect, connector):
    """Get the details of a single connector."""
    connectors = kafka_connect.get_connectors(connector)
    click.echo(json.dumps(connectors))

@cli.command()
@click.option('--expand', type=click.Choice(['status', 'info']), envvar='KAFKA_CONNECT_EXPAND', help='Optional parameter that retrieves additional information about the connectors.')
@click.pass_obj
def get_connectors(kafka_connect, expand):
    """Get a list of active connectors."""
    connectors = kafka_connect.get_connectors(expand=expand)
    click.echo(json.dumps(connectors))

@cli.command()
@click.argument('config', type=click.File('r'))
@click.pass_obj
def create_connector(kafka_connect, config):
    """Create a new connector, returning the current connector info if successful. Return 409 (Conflict) if rebalance is in process, or if the connector already exists."""
    config_data = config.read()
    response = kafka_connect.create_connector(json.loads(config_data))
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.argument('config', type=click.File('r'))
@click.pass_obj
def put_connector(kafka_connect, connector, config):
    """Create a new connector using the given configuration, or update the configuration for an existing connector. Returns information about the connector after the change has been made. Return 409 (Conflict) if rebalance is in process."""
    config_data = config.read()
    response = kafka_connect.put_connector(connector, json.loads(config_data))
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def get_connector(kafka_connect, connector):
    """Gets the configuration of a connector."""
    response = kafka_connect.get_connector(connector)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def get_connector_config(kafka_connect, connector):
    """Gets the config of a connector."""
    response = kafka_connect.get_connector_config(connector)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def get_connector_status(kafka_connect, connector):
    """Gets the status of a connector."""
    response = kafka_connect.get_connector_status(connector)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.option('--include-tasks', is_flag=True, default=False, envvar='KAFKA_CONNECT_INCLUDE_TASKS', help='Whether to include the Task objects in the restart operation.')
@click.option('--only-failed', is_flag=True, default=False, envvar='KAFKA_CONNECT_ONLY_FAILED', help='Whether to restart only failed Task objects.')
@click.pass_obj
def restart_connector(kafka_connect, connector, include_tasks, only_failed):
    """Restart a connector."""
    response = kafka_connect.restart_connector(connector, include_tasks=include_tasks, only_failed=only_failed)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def pause_connector(kafka_connect, connector):
    """Pauses a connector."""
    response = kafka_connect.pause_connector(connector)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def resume_connector(kafka_connect, connector):
    """Resumes a connector."""
    response = kafka_connect.resume_connector(connector)
    click.echo

@cli.command()
@click.argument('connector')
@click.pass_obj
def delete_connector(kafka_connect, connector):
    """Deletes a connector."""
    response = kafka_connect.delete_connector(connector)
    click.echo

@cli.command()
@click.argument('connector')
@click.option('--include-tasks', is_flag=True, default=False, envvar='KAFKA_CONNECT_INCLUDE_TASKS', help='Whether to include the Task objects in the restart operation.')
@click.pass_obj
def get_connector_tasks(kafka_connect, connector):
    """Gets the list of tasks associated with a connector."""
    response = kafka_connect.get_connector_tasks(connector)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.argument('task_id')
@click.pass_obj
def get_connector_task(kafka_connect, connector, task_id):
    """Gets the configuration of a task associated with a connector."""
    response = kafka_connect.get_connector_task(connector, task_id)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.argument('task_id')
@click.pass_obj
def get_connector_task_status(kafka_connect, connector, task_id):
    """Gets the status of a task associated with a connector."""
    response = kafka_connect.get_connector_task_status(connector, task_id)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.argument('task_id')
@click.pass_obj
def restart_connector_task(kafka_connect, connector, task_id):
    """Restart a specific task of a connector."""
    response = kafka_connect.restart_connector_task(connector, task_id)
    click.echo(json.dumps(response))

@cli.command()
@click.argument('connector')
@click.pass_obj
def get_connector_topics(kafka_connect, connector):
    """Get the list of topics for a connector."""
    response = kafka_connect.get_connector_topics(connector)
    click.echo

@cli.command()
@click.argument('connector')
@click.pass_obj
def reset_connector_topics(kafka_connect, connector):
    """Reset the list of topics for a connector."""
    response = kafka_connect.reset_connector_topics(connector)
    click.echo

@cli.command()
@click.pass_obj
def get_connector_plugins(kafka_connect):
    """Get the list of connector plugins."""
    response = kafka_connect.get_connector_plugins()
    click.echo

@cli.command()
@click.argument('plugin')
@click.argument('config', type=click.File('r'))
@click.pass_obj
def validate_connector_config(kafka_connect, plugin, config):
    """Validate the configuration for a specific connector plugin."""
    config_data = config.read()
    response = kafka_connect.validate_connector_config(plugin, json.loads(config_data))
    click.echo(json.dumps(response))



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['kafka_connect']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'requests>=2.25,<3.0']

entry_points = \
{'console_scripts': ['kafka-connect = kafka_connect.cli:cli',
                     'kc = kafka_connect.cli:cli']}

setup_kwargs = {
    'name': 'kafka-connect-py',
    'version': '0.2.3',
    'description': 'A client for the Confluent Platform Kafka Connect REST API.',
    'long_description': '# Kafka Connect Python\n\nThe Kafka Connect REST API allows you to manage connectors that move data between Apache Kafka and other systems.\n\nThe `kc` command line tool provides commands for getting information about the Kafka Connect cluster and its connectors, creating new connectors, updating existing connectors, deleting connectors, etc.\n\nThis project aims to supported all features of the [Kafka Connect REST API](https://docs.confluent.io/platform/current/connect/references/restapi.html#kconnect-rest-interface).\n\n## Install\n\n```bash\npip install kafka-connect-py\n```\n\n## Command Line Usage\n\nRetrieve the version and other details of the Kafka Connect cluster.\n\n```bash\n$ kc get-cluster\n```\n\nRetrieve the details of a single connector.\n\n```bash\n$ kc get-connector <connector>\n```\n\nRetrieve a list of active connectors. The `--expand\' option can be used to retrieve additional information about the connectors, such as their status or metadata.\n\n```bash\n$ kc get-connectors [--expand=status|info]\n```\n\nCreate a new connector using the configuration specified in the given file. If the connector already exists or a rebalance is in process, Wil return a status code of 409.\n\n```bash\n$ kc create-connector <config_file>\n```\n\nUpdate the configuration for an existing connector. If a rebalance is in process, Wil return a status code of 409.\n\n```bash\n$ kc update-connector <connector> <config_file>\n```\n\nRetrieve the configuration of a connector.\n\n```bash\n$ kc get-connector <connector>\n```\n\nRetrieve the config of a connector.\n\n```bash\n$ kc get-connector-config <connector>\n```\n\nRetrieve the status of a connector.\n\n```bash\n$ kc get-connector-status <connector>\n```\n\nRetrieve the tasks of a connector. The `--include-tasks\' option can be used to include task information in the response.\n\n```bash\n$ kc get-connector-tasks <connector> [--include-tasks]\n```\n\nPause a connector.\n\n```bash\n$ kc pause-connector <connector>\n```\n\nResume a connector that was previously paused.\n\n```bash\n$ kc resume-connector <connector>\n```\n\nDelete a connector.\n\n```bash\n$ kc delete-connector <connector>\n```\n\nValidate the configuration specified in the given file. If the configuration is valid, Wil return a status code of 200.\n\n```bash\n$ kc validate-connector-config <config_file>\n```\n\nRetrieve metadata about the specified connector plugin.\n\n```bash\n$ kc get-connector-plugin <connector>\n```\n\nRetrieve metadata about all available connector plugins.\n\n```bash\n$ kc get-connector-plugins\n```\n\n\n### Python\n\n```python\n# Import the class\nfrom kafka_connect import KafkaConnect\n\n# Instantiate the client\nclient = KafkaConnect(endpoint="http://localhost:8083")\n\n# Get the version and other details of the Kafka Connect cluster\ncluster = client.get_cluster()\nprint(cluster)\n\n# Get a list of active connectors\nconnectors = client.get_connectors()\nprint(connectors)\n\n# Create a new connector\nconfig = {\n    "name": "my-connector",\n    "config": {\n        "connector.class": "io.confluent.connect.jdbc.JdbcSourceConnector",\n        "tasks.max": "1",\n        "connection.url": "jdbc:postgresql://localhost:5432/mydatabase",\n        "connection.user": "myuser",\n        "connection.password": "mypassword",\n        "table.whitelist": "mytable",\n        "mode": "timestamp+incrementing",\n        "timestamp.column.name": "modified_at",\n        "validate.non.null": "false",\n        "incrementing.column.name": "id",\n        "topic.prefix": "my-connector-",\n    },\n}\nresponse = client.create_connector(config)\nprint(response)\n\n# Update an existing connector\nnew_config = {\n    "config": {\n        "connector.class": "io.confluent.connect.jdbc.JdbcSourceConnector",\n        "tasks.max": "1",\n        "connection.url": "jdbc:postgresql://localhost:5432/mydatabase",\n        "connection.user": "myuser",\n        "connection.password": "mypassword",\n        "table.whitelist": "mytable",\n        "mode": "timestamp+incrementing",\n        "timestamp.column.name": "modified_at",\n        "validate.non.null": "false",\n        "incrementing.column.name": "id",\n        "topic.prefix": "my-connector-",\n    },\n}\nresponse = client.update_connector("my-connector", new_config)\nprint(response)\n\n# Restart a connector\nresponse = client.restart_connector("my-connector")\nprint(response)\n\n# Delete a connector\nresponse = client.delete_connector("my-connector")\nprint(response)\n```\n\n## Tests\n\n```\npython3 -m unittest tests/test_kafka_connect.py -v\n```',
    'author': 'Aidan Melen',
    'author_email': 'aidan-melen@protonmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
